@@ -16,8 +16,6 @@ qx.Class.define("callbackery.ui.plugin.Action", {
      * @param vizWidget {Widget} visualization widget to embedd
      */
     construct : function(cfg,buttonClass,layout,getFormData) {
-        /* using syntax trick to not get a warning for translating
-           a variable */
         this.base(arguments, layout);
         this._populate(cfg,buttonClass,getFormData);
         this.addListener('actionResponse',function(e){
@@ -53,9 +51,13 @@ qx.Class.define("callbackery.ui.plugin.Action", {
     },
     members: {
         _cfg: null,
+        _tableMenu: null,
+        _defaultAction: null,
         _populate: function(cfg,buttonClass,getFormData){
+            var tm = this._tableMenu =  new qx.ui.menu.Menu;
             cfg.action.forEach(function(btCfg){
                 var button;
+                var menuButton;
                 switch (btCfg.action) {
                     case 'submitVerify':
                     case 'submit':
@@ -64,7 +66,9 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     case 'cancel':
                     case 'download':
                         button = new buttonClass(this['tr'](btCfg.label));
-                        this.add(button);
+                        if ( btCfg.addToContextMenu ){
+                             menuButton = new qx.ui.menu.Button(this['tr'](btCfg.label));
+                        }
                         break;
                     case 'refresh':
                         var timer = qx.util.TimerManager.getInstance();
@@ -84,10 +88,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     default:
                         this.debug('Invalid execute action:' + btCfg.action);
                 }
-                if (button == null){
-                    return;
-                }
-                button.addListener('execute',function(){
+                var action = function(){
                     switch (btCfg.action) {
                         case 'submitVerify':
                         case 'submit':
@@ -193,7 +194,19 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         default:
                             this.debug('Invalid execute action:' + btCfg.action);
                     }
-                },this);
+                };
+
+                if (btCfg.defaultAction){
+                    this._defaultAction = action;
+                }
+                if (button){
+                    button.addListener('execute',action,this);
+                    this.add(button);
+                }
+                if (menuButton){
+                    menuButton.addListener('execute',action,this);
+                    this._tableMenu.add(menuButton);
+                }
             },this);
         },
         _addUploadButton: function(cfg,btCfg,getFormData){
@@ -257,6 +270,14 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                 }
             },this);
 
+        },
+
+        getTableContextMenu: function(){
+            return this._tableMenu;
+        },
+
+        getDefaultAction: function(){
+            return this._defaultAction;
         }
     }
 });
